@@ -54,8 +54,12 @@ DataEngine::DataEngine(const KPluginMetaData &plugin, QObject *parent)
 
 DataEngine::DataEngine(QObject *parent, const QVariantList &args)
     : QObject(parent)
-    , d(new DataEnginePrivate(this, KPluginInfo(args).toMetaData(), args))
 {
+    KPluginMetaData data;
+    if (args.size() > 1 && args.first().canConvert<KPluginMetaData>()) {
+        data = args.first().value<KPluginMetaData>();
+    }
+    d = new DataEnginePrivate(this, data, args);
     if (d->script) {
         d->setupScriptSupport();
         d->script->init();
@@ -122,7 +126,7 @@ void DataEngine::connectSource(const QString &source, QObject *visualization, ui
 
 void DataEngine::connectAllSources(QObject *visualization, uint pollingInterval, Plasma::Types::IntervalAlignment intervalAlignment) const
 {
-    for (DataContainer *s : qAsConst(d->sources)) {
+    for (DataContainer *s : std::as_const(d->sources)) {
         d->connectSource(s, visualization, pollingInterval, intervalAlignment);
     }
 }
@@ -380,7 +384,7 @@ void DataEngine::updateAllSources()
 
 void DataEngine::forceImmediateUpdateOfAllVisualizations()
 {
-    for (DataContainer *source : qAsConst(d->sources)) {
+    for (DataContainer *source : std::as_const(d->sources)) {
         if (source->isUsed()) {
             source->forceImmediateUpdate();
         }
@@ -436,10 +440,6 @@ DataEnginePrivate::DataEnginePrivate(DataEngine *e, const KPluginMetaData &md, c
             }
 
             if (!script) {
-#ifndef NDEBUG
-                // qCDebug(LOG_PLASMA) << "Could not create a" << api << "ScriptEngine for the"
-                //        << dataEngineDescription.name() << "DataEngine.";
-#endif
                 delete package;
                 package = nullptr;
             }
@@ -473,11 +473,7 @@ void DataEnginePrivate::internalUpdateSource(DataContainer *source)
     if (q->updateSourceEvent(source->objectName())) {
         // qCDebug(LOG_PLASMA) << "queuing an update";
         scheduleSourcesUpdated();
-    } /* else {
- #ifndef NDEBUG
-         // qCDebug(LOG_PLASMA) << "no update";
- #endif
-     }*/
+    }
 }
 
 void DataEnginePrivate::ref()
